==> pdapi-0.1.4-sources.jar: ml/pluto7073/pdapi/block/DrinkWorkstationBlock.java <==
package ml.pluto7073.pdapi.block;

import ml.pluto7073.pdapi.client.gui.DrinkWorkstationScreenHandler;
import ml.pluto7073.pdapi.item.PDItems;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2304;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_3908;
import net.minecraft.class_3914;
import net.minecraft.class_3965;
import net.minecraft.class_747;

public class DrinkWorkstationBlock extends class_2304 {

    public static final class_2561 TITLE = class_2561.method_43471("container.drink_workstation");

    public DrinkWorkstationBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_9534(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
        if (world.field_9236) {
            return class_1269.field_5812;
        } else {
            player.method_17355(state.method_26196(world, pos));
            //player.incrementStat();
            return class_1269.field_21466;
        }
    }

    @Override
    public class_3908 method_17454(class_2680 state, class_1937 world, class_2338 pos) {
        return new class_747((syncId, playerInventory, playerEntity) -> new DrinkWorkstationScreenHandler(syncId, playerInventory, class_3914.method_17392(world, pos)), TITLE);
    }

    @Override
    public class_1792 method_8389() {
        return PDItems.DRINK_WORKSTATION;
    }

    @Override
    public class_1799 method_9574(class_1922 world, class_2338 pos, class_2680 state) {
        return new class_1799(PDItems.DRINK_WORKSTATION, 1);
    }

}

==> pdapi-1.20.1+0.1.6.5-sources.jar: ml/pluto7073/pdapi/block/DrinkWorkstationBlock.java <==
package ml.pluto7073.pdapi.block;

import ml.pluto7073.pdapi.client.gui.DrinkWorkstationMenu;
import ml.pluto7073.pdapi.item.PDItems;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2304;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_3908;
import net.minecraft.class_3914;
import net.minecraft.class_3965;
import net.minecraft.class_6328;
import net.minecraft.class_747;

@class_6328
public class DrinkWorkstationBlock extends class_2304 {

    public static final class_2561 TITLE = class_2561.method_43471("container.drink_workstation");

    public DrinkWorkstationBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_9534(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
        if (world.field_9236) {
            return class_1269.field_5812;
        } else {
            player.method_17355(state.method_26196(world, pos));
            //player.incrementStat();
            return class_1269.field_21466;
        }
    }

    @Override
    public class_3908 method_17454(class_2680 state, class_1937 world, class_2338 pos) {
        return new class_747((syncId, playerInventory, playerEntity) -> new DrinkWorkstationMenu(syncId, playerInventory, class_3914.method_17392(world, pos)), TITLE);
    }

    @Override
    public class_1792 method_8389() {
        return PDItems.DRINK_WORKSTATION;
    }

    @Override
    public class_1799 method_9574(class_1922 world, class_2338 pos, class_2680 state) {
        return new class_1799(PDItems.DRINK_WORKSTATION, 1);
    }

}
